==> haskell-wuss-2.0.1.4-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wuss
version:              2.0.1.4
visibility:           public
id:                   wuss-2.0.1.4-5k0JftRK5VDHZX2AKr12LI
key:                  wuss-2.0.1.4-5k0JftRK5VDHZX2AKr12LI
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  9350e0afaaae6fd81ce6a592ab03f7e7
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.4-5k0JftRK5VDHZX2AKr12LI
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    crypton-connection-0.4.3-JT6KOKF9R62GJoCkvj83oi exceptions-0.10.5
    network-3.1.4.0-Ds1jGwhI6OBB7cQ3449UkE
    websockets-0.12.7.3-KjaKtLUYAZDHjGfJrwvMuR

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wuss-2.0.1.4-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wuss
version:              2.0.1.4
visibility:           public
id:                   wuss-2.0.1.4-426qhvHNb1C336MalVzSsI
key:                  wuss-2.0.1.4-426qhvHNb1C336MalVzSsI
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  226a5bf9dc77ddf5600f1b5fdba80833
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.4-426qhvHNb1C336MalVzSsI
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    crypton-connection-0.4.3-H3ncZDjtQBPI0hjNM9c8w6 exceptions-0.10.5
    network-3.1.4.0-Lt9YSaQDSdWKRzslp3ePNQ
    websockets-0.12.7.3-LIBcJtw8PXtG13zaxAJJXh

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
